/*-----------------------------------------------
	Draw a field of arrows in the Mgraph main window
------------------------------
  COMMON VARIABLES:
     int Mgraph_no Sequence number of the software;
                      several Mgraph can be launched at the same time id (several Mgraph can be launched)
     int nwindow   Number of window in which the data will be shown (-1=Current)
     int color     Number of the color: from 0 to 12:
                          Red, Blue, Magenta, Black, Green, Forest, Sienna,
                          Yellow, Coral, Violet, Plum, Cyan, Turquoise
                          Plum, Cyan,Turquoise
                      and 16 for the White
     int linestyle Style of the line: from 0 to 7:
                          Solid, NoLine, MicroDash, SmallDash,
                         Dash, LongDash, DashDot, LineDot
     int marker    Style of the marker: from 0 to 15:
                          NoMark, BigDot, SmallDot, Cross, X, Square,
                          Diamond, TriangleUp, TriangleDown, Circle
                          filled: Square, Diamond, TriangleUp, TriangleDown, Circle
-----------------------------------------------*/

#include <stdio.h>
#include <math.h>

#define FALSE 0
#define TRUE  1

#define LOGIN ""
#define SHELL "remsh"
#define PATH "/usr/local/bin"
#define PROG "Mgraph_sp"
#define COMPUTER ""
#define DISPLAY ""


main()
{
float *xx,*yy,*rho,*theta;
int Mgraph_no=1,i,j,nbp;
FILE *fd;
int max_nbp=7000;
int nwindow;
float xmin,xmax,ymin,ymax;
int   grid;
float xstep,ystep;
float xbase,ybase;
int   ixtic,iytic;
int   ixlog,iylog;


/*========================================================================================
 START MGRAPH_SP MODULE: run_mgraph
        LOGIN:  login name;             if NULL will be the current login
        SHELL:  "rsh" or "remsh";       if NULL will be  "remsh"
        PATH :  path where the program is
        PROG :  name of the program (Mgraph_sp)
        COMPUTER:       name of the computer where the program has to
                        be launched;    if NULL will be the server name
        DISPLAY: Your Display Id;       if NULL will be your DISPLAY address
                                             from your environment
==========================================================================================*/

        if( !run_mgraph(Mgraph_no,LOGIN,SHELL,PATH,PROG,COMPUTER,DISPLAY) )
        {
                printf("Cannot start Mgraph\n");
                exit(0);
        }

	xx = (float *) malloc( max_nbp * sizeof(float));
	yy = (float *) malloc( max_nbp * sizeof(float));
	rho = (float *) malloc( max_nbp * sizeof(float));
	theta = (float *) malloc( max_nbp * sizeof(float));

/*-----------------------------------------------
 	Data file read 
------------------------------------------------*/
	fd = fopen("961101.vent.pas01.LatLon","r");
	nbp=0;
	while( (i=fscanf(fd,"%g%g%g%g",&xx[nbp],&yy[nbp],&rho[nbp],&theta[nbp])) == 4
		&& nbp < max_nbp ){
	    nbp++;
	}
 	fclose(fd);
	printf("Number of points: %d\n",nbp);

/*=========================================================================================
SEND TITLE
        char title[] = the text which is to be shown
==========================================================================================*/

        send_title(Mgraph_no,nwindow,"Field of winds");

/*=========================================================================================
SEND AXES
send_xaxes2(client_id,window,legend,format,label_size,min,max,grid,
            color,thickness,rotation,step,ref,tick,log,Formula);

        CAREFUL with types !!!
      char  legend               The text which is displayed under the axis
      char  format               the C format formulation   ("%.2f" for ex.)
      float label size           factor on label size
      float min,max              the limits of axis (-1 : uses the best)
      int   grid                 10= grid 11= half tone 12= no grid
      int   color                color type (3=black)
      int   thickness            thickness of the line factor
      float rotation             label text rotation in degrees
      float step                 the step in your units between two ticks (-1:uses the best)
      float ref                  reference value   (-1 : uses the best)
      int   tick                 step (in ticks) between two labeled ticks  (-1 : uses the best)
      int   log                  0=linear 1=logarithm  2=formula 3=time  4=degree
      char  Formula[]            (if log = 2)
============================================================================================*/

      xmin = 4.;
      xmax = 10.;
      xstep= -1.;
      xbase= -1.;
      grid= 12;
      ixtic= -1;
      ixlog=  0;

        send_xaxes2(Mgraph_no,nwindow,"","%.2f",1.0,
                        xmin,xmax,grid,3,1,0.0,xstep,xbase,ixtic,ixlog,"");

      ymin = -17.;
      ymax = -11.;
      ystep= -1.;
      ybase= -1.;
      iytic= -1;
      iylog=  0;

        send_yaxes2(Mgraph_no,nwindow,"","%.2f",1.0,
                        ymin,ymax,grid,3,1,0.0,ystep,ybase,iytic,iylog,"");


/*===========================================================================
SEND DATA ON WINDOW

send_data_arrows( client_id,nwindow,clear,plot_no,nbp,xx,yy,rho,theta,lenfactor,
		arrowfact,color,linestyle,marker,thickness,marksize)

     int   clear      does the window have it to be cleared? (0=no 1=yes)
     int   plot_no    Number of the curve (-1 will determine an available one)
     int   nbp        Number of points in the data
     float xx         x    data
     float yy         f(x) data
     float rho        length of the vector
     float theta      orientation of the vector
     float lenfactor  length factor
     float arrowfact  arrow size factor
     int   thickness  thickness of the line (factor)
     int   marksize   marker size (factor)
==========================================================================*/

	send_data_arrows( Mgraph_no,-1,FALSE,1,nbp,xx,yy,rho,theta,.5,1.0,1,0,0,4,1);

/*===========================================================================
        EXIT_MAIN_PROGRAM
        before quitting your main program,  call send_end_dialog
        to keep Mgraph running
==========================================================================*/

	send_end_dialog(Mgraph_no);

	free(xx);
	free(yy);
	free(rho);
	free(theta);
}
